==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/history/translations/history_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation>Historie rozhovorů</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Uložit zprávy v historii</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation>Uložit rozhovory s neznámými uživateli</translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation>Změny stavu</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Uložit změny stavu</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Uložit změny stavu v historii</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation>Uložit stav pouze s popisem</translation>
    </message>
    <message>
        <source>Quotation</source>
        <translation>Citace</translation>
    </message>
    <message>
        <source>Quote message in chat window</source>
        <translation>Citovat zprávu v okně s rozhovorem</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Zobrazit historii</translation>
    </message>
    <message>
        <source>Do not quote messages older than</source>
        <translation>Necitovat zprávy starší než</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
</context>
<context>
    <name>ChatHistoryTab</name>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation>&amp;Smazat historii rozhovoru</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation>Smazat historii</translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation>%1 den/dny/dnů %2 hodinu/hodiny/hodin</translation>
    </message>
</context>
<context>
    <name>HistoryBuddyDataWindowAddons</name>
    <message>
        <source>Store history</source>
        <translation>Uchovávat historii</translation>
    </message>
</context>
<context>
    <name>HistoryChatDataWindowAddons</name>
    <message>
        <source>Store history</source>
        <translation>Uchovávat historii</translation>
    </message>
</context>
<context>
    <name>HistoryMessagesTab</name>
    <message>
        <source>&amp;Remove entries</source>
        <translation>&amp;Odstranit záznamy</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Do you really want to delete history?</source>
        <translation>Opravdu chcete smazat historii</translation>
    </message>
</context>
<context>
    <name>HistoryQueryResultsModel</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation>&amp;Smazat stavovou historii</translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation>&amp;Smazat historii SMS</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Rozhovory</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Stavy</translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Chat history</source>
        <translation>Historie rozhovoru</translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search for:</source>
        <translation>Hledat:</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Rozhovory</translation>
    </message>
    <message>
        <source> - All chats - </source>
        <translation> - Všechny rozhovory - </translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Stavy</translation>
    </message>
    <message>
        <source> - All buddies - </source>
        <translation> - Všichni kamarádi - </translation>
    </message>
    <message>
        <source>Smses</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source> - All recipients - </source>
        <translation> - Všichni příjemci - </translation>
    </message>
    <message>
        <source>By date</source>
        <translation>Podle data</translation>
    </message>
    <message>
        <source>to</source>
        <translation>do</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledání</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Nalezeno</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Buddy</source>
        <translation>Kamarád</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Příjemce</translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation>Zobrazit historii rozhovoru</translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation>Ukázat poslední %1 zprávy</translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation>Ukázat zprávy od včerejška</translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation>Ukázat zprávy z posledních sedmi dní</translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation>Ukázat zprávy z posledních třiceti dní</translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation>Ukázat celou historii</translation>
    </message>
</context>
</TS>

==> kadu_1.3.orig.tar.bz2: kadu-1.3/plugins/history/translations/history_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation>Historie rozhovorů</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Uložit zprávy v historii</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation>Uložit rozhovory s neznámými uživateli</translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation>Změny stavu</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Uložit změny stavu</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Uložit změny stavu v historii</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation>Uložit stav pouze s popisem</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Zobrazit historii</translation>
    </message>
    <message>
        <source>Save chats in history</source>
        <translation>Ukládat rozhovory v historii</translation>
    </message>
    <message>
        <source>History in chat window</source>
        <translation>Historie v okně s rozhovorem</translation>
    </message>
    <message>
        <source>Show messages from history since</source>
        <translation>Ukázat zprávy z historie od</translation>
    </message>
    <message>
        <source>Choose time period in which messages can be quoted in chat window</source>
        <translation>Zvolit časové období, pro které mohou být zprávy uvedeny v okně s rozhovorem</translation>
    </message>
    <message>
        <source>yesterday</source>
        <translation>Včera</translation>
    </message>
    <message>
        <source>last week</source>
        <translation>Minulý týden</translation>
    </message>
    <message>
        <source>last month</source>
        <translation>Minulý měsíc</translation>
    </message>
    <message>
        <source>Limit number of messages from history</source>
        <translation>Omezit počet zpráv z historie</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Chování</translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation>Okno pro rozhovor</translation>
    </message>
</context>
<context>
    <name>BuddyHistoryDeleteHandler</name>
    <message>
        <source>Chat history</source>
        <translation>Historie rozhovoru</translation>
    </message>
</context>
<context>
    <name>ChatHistoryTab</name>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation>&amp;Smazat historii rozhovoru</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation>Smazat historii</translation>
    </message>
</context>
<context>
    <name>HistoryBuddyConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation>Ukládat historii</translation>
    </message>
</context>
<context>
    <name>HistoryChatConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation>Ukládat historii</translation>
    </message>
</context>
<context>
    <name>HistoryMessagesTab</name>
    <message>
        <source>&amp;Remove entries</source>
        <translation>&amp;Odstranit záznamy</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Do you really want to delete history?</source>
        <translation>Opravdu chcete smazat historii?</translation>
    </message>
    <message>
        <source>Delete history</source>
        <translation>Smazat historii</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>HistoryQueryResultsModel</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation>&amp;Smazat stavovou historii</translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation>&amp;Smazat historii SMS</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Rozhovory</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Stavy</translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search for:</source>
        <translation>Hledat:</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Rozhovory</translation>
    </message>
    <message>
        <source> - All chats - </source>
        <translation> - Všechny rozhovory - </translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Stavy</translation>
    </message>
    <message>
        <source> - All buddies - </source>
        <translation> - Všichni kamarádi - </translation>
    </message>
    <message>
        <source>Smses</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source> - All recipients - </source>
        <translation> - Všichni příjemci - </translation>
    </message>
    <message>
        <source>By date</source>
        <translation>Podle data</translation>
    </message>
    <message>
        <source>to</source>
        <translation>do</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledání</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Nalezeno</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Buddy</source>
        <translation>Kamarád</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Příjemce</translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation>Zobrazit historii rozhovoru</translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation>Ukázat poslední %1 zprávy</translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation>Ukázat zprávy od včerejška</translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation>Ukázat zprávy z posledních sedmi dní</translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation>Ukázat zprávy z posledních třiceti dní</translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation>Ukázat celou historii</translation>
    </message>
</context>
</TS>
